==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/mediaplayer/translations/mediaplayer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Syntax: %t - Titel
%a - Album, %r - Interpret, %f - Dateiname
%l - Dauer (MM:SS), %c - Aktuelle Position (MM:SS)
%p - Prozent des Liedes gespielt, %n - Programmname, %v - Programmversion</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD für MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Format der Nachricht des MediaPlayer für das Chat-Fenster</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Zustand-Beschreibung vom MediaPlayer</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Format der MediaPlayer-Beschreibung</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>HIer geben Sie die Formatierung an, die den &apos;#{player}&apos;-Tag in der Zustandbeschreibung ersetzen soll, wenn Sie es nutzen wollen.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Signaturen zum abschneiden</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Rest zum Abschneiden</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Pseudo-OSD einschalten</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Schaltet Pseudo-OSD aus Kadu-Hinweisen ein. Zeigt aktuell gespielten Titel im Hinweis.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Tastenkürzel für die Bedienung des Abspielprogramms im Chat-Fenster einschalten</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Schalter für Zustandbeschreibung im Dock-Menü</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Schalten Sie es ein, wenn sie Zustandbeschreibungen aus dem Menü des Symbols im Systemabschnitt der Kontrolleiste ein und ausschalten wollen.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Formatierten Text einfügen</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Liedtitel einfügen</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Dateinamen einfügen</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Sende alle Titel aus der Playliste</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Sende alle Dateien aus der Playliste</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>MediaPlayer-Zustandbeschreibungen einschalten</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 - läuft nicht!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Sie haben versucht %1 Einträge der Playliste %2 zu senden.&lt;br&gt;Es wird aufgeteilt in mehrere Nachrichten.&lt;br&gt;Soll ich fortfahren?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Abspielen angehalten.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Abspielprogramm läuft nicht.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/mediaplayer/translations/mediaplayer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Syntax: %t - Titel
%a - Album, %r - Interpret, %f - Dateiname
%l - Dauer (MM:SS), %c - Aktuelle Position (MM:SS)
%p - Prozent des Liedes gespielt, %n - Programmname, %v - Programmversion</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD für MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Zustand-Beschreibung vom MediaPlayer</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Format der MediaPlayer-Beschreibung</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>HIer geben Sie die Formatierung an, die den &apos;#{player}&apos;-Tag in der Zustandbeschreibung ersetzen soll, wenn Sie es nutzen wollen.</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Signaturen zum abschneiden</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Rest zum Abschneiden</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Pseudo-OSD einschalten</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Schaltet Pseudo-OSD aus Kadu-Hinweisen ein. Zeigt aktuell gespielten Titel im Hinweis.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Tastenkürzel für die Bedienung des Abspielprogramms im Chat-Fenster einschalten</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Schalter für Zustandbeschreibung im Dock-Menü</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Schalten Sie es ein, wenn sie Zustandbeschreibungen aus dem Menü des Symbols im Systemabschnitt der Kontrolleiste ein und ausschalten wollen.</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extras</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MediaPlayer message format in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable signature cutting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable removing non-essential stuff from audio file titles</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Formatierten Text einfügen</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Liedtitel einfügen</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Dateinamen einfügen</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Sende alle Titel aus der Playliste</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Sende alle Dateien aus der Playliste</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>MediaPlayer-Zustandbeschreibungen einschalten</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 - läuft nicht!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Sie haben versucht %1 Einträge der Playliste %2 zu senden.&lt;br&gt;Es wird aufgeteilt in mehrere Nachrichten.&lt;br&gt;Soll ich fortfahren?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Abspielen angehalten.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Abspielprogramm läuft nicht.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous Track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next Track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Volume Up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Volume Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send anyway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
